;; $Id: dbdivis.dsl 1.0 1997/12/30 17:48:14 nwalsh Exp $
;;
;; This file is part of the Modular DocBook Stylesheet distribution.
;; See ../README or http://www.berkshire.net/~norm/dsssl/
;;

;; ============================= DIVISIONS ==============================

(define ($division$) 
  (make element gi: "DIV"
	attributes: (list
		     (list "CLASS" (gi)))
	($division-title$)
	(process-children)))

(define ($division-title$)
  (let* ((info (cond
		((equal? (gi) "SET")
		 (select-elements (children (current-node)) "SETINFO"))
		((equal? (gi) "BOOK")
		 (select-elements (children (current-node)) "BOOKINFO"))
		(else 
		 (select-elements (children (current-node)) "DOCINFO"))))
	 (parent-titles (select-elements (children (current-node)) "TITLE"))
	 (info-titles   (select-elements (children info) "TITLE"))
	 (titles        (if (node-list-empty? parent-titles)
			    info-titles
			    parent-titles))
	 (subtitles     (select-elements (children info) "SUBTITLE"))
	 (nsep (gentext-label-title-sep (gi))))
    (make sequence
      (make element gi: "H1"
	    (if (string=? (element-label (current-node)) "")
		(empty-sosofo)
		(literal (element-label (current-node)) nsep))
	    (element-title-sosofo (current-node)))
      (if (node-list-empty? subtitles) 
	  (empty-sosofo)
	  (with-mode subtitle-mode
	    (make element gi: "H2"
		  (process-node-list subtitles)))))))

(element SET ($division$))
(element (SET TITLE) (empty-sosofo))

(define ($book-body$)
  ;; Handle two cases:
  ;;   If there's a BOOKINFO, just process children.  BOOKINFO will handle
  ;;      generation of a title page and/or a TOC (see dbttlpg.dsl and 
  ;;      dbinfo.dsl)
  ;;   If there's no BOOKINFO, generate a simple page sequence containing
  ;;      the TOC, if a TOC is desired
  ;;
  (let* ((btitle (select-elements (children (current-node)) "TITLE"))
	 (binfo  (select-elements (children (current-node)) "BOOKINFO"))
	 (title  (if (node-list-empty? btitle)
		     (select-elements (children binfo) "TITLE")
		     btitle))
	 (subtitle (select-elements (children binfo) "SUBTITLE"))
	 (dedic  (select-elements (children (current-node)) "DEDICATION")))
    (make sequence
      (if (node-list-empty? binfo)
	  ($division-title$)
	  (with-mode titlepage-mode
	    (process-node-list binfo)))
      
      (if (node-list-empty? dedic)
	  (empty-sosofo)
	  (with-mode dedication-mode
	    (process-node-list dedic)))
      
      (if (and %generate-toc% %generate-toc-in-front%)
	  (build-toc (current-node)
		     (toc-depth (current-node)))
	  (empty-sosofo))

      (process-children))))

(element BOOK 
  (let* ((btitle (select-elements (children (current-node)) "TITLE"))
	 (binfo  (select-elements (children (current-node)) "BOOKINFO"))
	 (title  (if (node-list-empty? btitle)
		     (select-elements (children binfo) "TITLE")
		     btitle)))
    (if (chunk?)
	(make entity
	  system-id: (html-file)
	  (make document-type
	    name: "HTML"
	    public-id: %html-pubid%)
	  (make element gi: "HTML"
		(make element gi: "HEAD"
		      (make element gi: "TITLE"
			    (with-mode title-mode
			      (process-node-list (node-list-first title))))
		      ($html-header-meta$))
		(make element gi: "BODY" 
		      attributes: %body-attr%
		      (header-navigation (current-node))
		      ($book-body$)
		      (footer-navigation (current-node)))))
	($book-body$))))

;; If the book title is present, then:
;;   If there's a BOOKINFO, we will have used that to make the title page,
;;      so ignore the BOOK TITLE
;;   Otherwise, generate a $divtitlepage$ with the BOOK TITLE
;;
(element (BOOK TITLE) (empty-sosofo))

(define ($part-body$)
  (make sequence
    ($division-title$)
    (if %generate-part-toc%
	(make sequence
	  (build-toc (current-node) (toc-depth (current-node)))
	  (process-children))
	(process-children))))

(element PART
  (let* ((title (select-elements (children (current-node)) "TITLE")))
    (if (chunk?)
	(make entity
	  system-id: (html-file)
	  (make document-type
	    name: "HTML"
	    public-id: %html-pubid%)
	  (make element gi: "HTML"
		(make element gi: "HEAD"
		      (make element gi: "TITLE"
			    (with-mode title-mode
			      (process-node-list (node-list-first title))))
		      ($html-header-meta$))
		(make element gi: "BODY" 
		      attributes: %body-attr%
		      (header-navigation (current-node))
		      ($part-body$)
		      (footer-navigation (current-node)))))
	($part-body$))))

(element (PART TITLE) (empty-sosofo))

(element PARTINTRO 
  (make element gi: "DIV"
	attributes: (list (list "CLASS" (gi)))
	(process-children)))

(element (PARTINTRO TITLE)
  (make element gi: "H1"
	(process-children)))
